==> ais_terminal-2.4.0.tar.gz: ais_terminal-2.4.0/docs/features/index.md <==
# 功能概览

AIS (AI Shell) 是一个**上下文感知的错误分析学习助手**，通过深度 Shell 集成，让每次命令行报错都成为学习和成长的机会。

## 🎯 核心功能

### 1. 智能错误分析
- **自动错误捕获**：通过 Shell 集成自动捕获命令执行错误
- **上下文感知**：收集网络状态、权限检查、项目类型等多维上下文信息
- **智能分析**：基于上下文信息生成针对性的错误解决方案
- **风险评估**：为每个建议标注安全等级（safe/moderate/dangerous）

### 2. AI 问答助手
- **即时问答**：快速获取技术问题的答案
- **上下文感知**：结合当前环境信息提供更准确的答案
- **流式输出**：实时显示 AI 处理进度
- **多模型支持**：支持 OpenAI、Claude、Ollama 等多种 AI 模型

### 3. 系统化学习
- **主题学习**：支持 Git、Docker、Vim、SSH 等主题的深度学习
- **渐进式内容**：根据用户水平调整教学深度
- **结构化输出**：使用 Markdown 格式提供易读的学习内容
- **个性化推荐**：基于用户历史行为的智能建议

### 4. 学习成长报告
- **错误模式分析**：统计最常见的错误类型和命令
- **技能评估**：基于历史错误数据评估用户技能水平
- **个性化建议**：生成针对性的学习建议和改进路径
- **趋势分析**：展示用户的学习进步趋势

### 5. 多 AI 提供商管理
- **内置免费服务**：安装后即可使用，无需配置API密钥
- **灵活切换**：支持多种 AI 服务提供商（OpenAI、Ollama等）
- **统一接口**：通过统一的命令行接口管理所有 AI 服务
- **本地模型支持**：支持 Ollama 等本地 AI 模型，保护隐私

## 🚀 快速开始

### 安装 AIS
```bash
# 一键安装脚本（推荐）
curl -sSL https://raw.githubusercontent.com/kangvcar/ais/main/scripts/install.sh | bash

# 国内用户可使用Gitee镜像
curl -sSL https://gitee.com/kangvcar/ais/raw/main/scripts/install.sh | bash

# 或者使用 pipx 安装
pipx install ais-terminal
```

### 自动配置完成
```bash
# 安装脚本会自动配置：
# - Shell 集成（自动错误分析）
# - AI 服务（内置免费服务）
# - 配置文件和数据库

# 验证安装
ais --version
ais test-integration
```

### 开始使用
```bash
# AI 问答
ais ask "如何使用 Docker 创建容器？"

# 错误分析（自动触发）
sudo systemctl start nonexistent-service
# AIS 会自动分析错误并提供解决方案

# 主题学习
ais learn git

# 查看学习报告
ais report

# 查看历史记录
ais history
```

## 🌟 使用场景

### 开发者
- **调试代码**：快速分析编译错误、运行时错误
- **环境配置**：解决依赖安装、环境配置问题
- **工具使用**：学习 Git、Docker、Kubernetes 等工具

### 系统管理员
- **系统诊断**：分析系统错误、服务问题
- **网络排障**：诊断网络连接、DNS 解析问题
- **权限管理**：解决用户权限、文件权限问题

### 学习者
- **技能提升**：系统化学习命令行工具
- **经验积累**：将错误转化为学习机会
- **进度跟踪**：通过学习报告了解自己的成长

## 🎨 用户体验

### 美观的界面
- **Rich 库美化**：彩色输出、进度条、表格
- **交互式菜单**：支持快捷键和智能排序
- **流式输出**：实时显示 AI 处理进度

### 智能交互
- **上下文感知**：根据当前环境提供更准确的建议
- **个性化推荐**：基于用户历史行为的智能建议
- **风险评估**：智能评估命令风险等级

### 隐私保护
- **本地存储**：所有数据存储在本地 SQLite 数据库
- **敏感信息过滤**：自动过滤密码、API 密钥等敏感信息
- **可配置的上下文级别**：用户可控制信息收集范围

## 🔧 技术特性

### 架构设计
- **模块化设计**：清晰的代码结构，易于扩展和维护
- **插件系统**：支持自定义插件和扩展
- **异步处理**：高性能的异步 I/O 处理

### 多平台支持
- **跨平台**：支持 Linux、macOS、Windows（WSL）
- **多 Shell 支持**：支持 Bash、Zsh，自动检测Shell类型
- **容器化**：提供 Docker 镜像，支持容器化部署
- **多发行版支持**：自动适配Ubuntu、CentOS、Debian、Rocky Linux等20+发行版

### 数据管理
- **本地数据库**：使用 SQLite 存储用户数据（`~/.local/share/ais/`）
- **配置管理**：TOML格式配置文件（`~/.config/ais/config.toml`）
- **隐私保护**：敏感数据过滤，支持本地AI模型

---

## 功能导航

| 功能 | 描述 | 链接 |
|------|------|------|
| [错误分析](./error-analysis) | 智能错误分析和解决方案 | 🧠 |
| [AI 问答](./ai-chat) | 智能问答助手 | 💬 |
| [学习系统](./learning-system) | 系统化技术学习 | 📚 |
| [学习报告](./learning-reports) | 个性化学习报告 | 📊 |
| [提供商管理](./provider-management) | AI 服务提供商管理 | ⚙️ |

---

## 下一步

- [安装指南](../getting-started/installation.md) - 开始安装 AIS
- [快速开始](../getting-started/quick-start.md) - 5 分钟快速上手
- [错误分析](./error-analysis.md) - 了解错误分析功能
- [AI 问答](./ai-chat.md) - 了解 AI 问答功能
- [学习系统](./learning-system.md) - 了解学习系统功能

---

::: tip 提示
AIS 的核心理念是将每次错误都转化为学习机会，帮助用户不断提升技能水平。
:::

::: info 开源项目
AIS 是一个开源项目，欢迎大家贡献代码和建议。
:::

::: warning 注意
AIS 优先保护用户隐私，所有数据本地存储，支持完全离线使用。
:::

==> ais_terminal-2.5.5.tar.gz: ais_terminal-2.5.5/docs/features/index.md <==
# 功能概览

AIS (AI Shell) 是一个**上下文感知的错误分析学习助手**，通过深度 Shell 集成，让每次命令行报错都成为学习和成长的机会。

## 🎯 核心功能

### 1. 智能错误分析
- **自动错误捕获**：通过 Shell 集成自动捕获命令执行错误
- **上下文感知**：收集网络状态、权限检查、项目类型等多维上下文信息
- **智能分析**：基于上下文信息生成针对性的错误解决方案
- **风险评估**：为每个建议标注安全等级（safe/moderate/dangerous）

### 2. AI 问答助手
- **即时问答**：快速获取技术问题的答案
- **上下文感知**：结合当前环境信息提供更准确的答案
- **流式输出**：实时显示 AI 处理进度
- **多模型支持**：支持 OpenAI、Claude、Ollama 等多种 AI 模型

### 3. 系统化学习
- **主题学习**：支持 Git、Docker、Vim、SSH 等主题的深度学习
- **渐进式内容**：根据用户水平调整教学深度
- **结构化输出**：使用 Markdown 格式提供易读的学习内容
- **个性化推荐**：基于用户历史行为的智能建议

### 4. 学习成长报告
- **文本格式报告**：详细的文本格式学习分析报告
- **HTML可视化报告**：交互式图表可视化，包含6种专业图表
- **错误模式分析**：统计最常见的错误类型和命令
- **技能评估雷达图**：多维度技能水平可视化展示
- **AI智能洞察**：基于多维数据的个性化深度分析
- **趋势分析**：错误减少和技能提升的可视化趋势

### 5. 多 AI 提供商管理
- **内置免费服务**：安装后即可使用，无需配置API密钥
- **灵活切换**：支持多种 AI 服务提供商（OpenAI、Ollama等）
- **统一接口**：通过统一的命令行接口管理所有 AI 服务
- **本地模型支持**：支持 Ollama 等本地 AI 模型，保护隐私

## 🚀 快速开始

### 安装 AIS
```bash
# 一键安装脚本（推荐）
curl -sSL https://raw.githubusercontent.com/kangvcar/ais/main/scripts/install.sh | bash

# 国内用户可使用Gitee镜像
curl -sSL https://gitee.com/kangvcar/ais/raw/main/scripts/install.sh | bash

# 或者使用 pipx 安装
pipx install ais-terminal
```

### 自动配置完成
```bash
# 安装脚本会自动配置：
# - Shell 集成（自动错误分析）
# - AI 服务（内置免费服务）
# - 配置文件和数据库

# 验证安装
ais --version
ais test-integration
```

### 开始使用
```bash
# AI 问答
ais ask "如何使用 Docker 创建容器？"

# 错误分析（自动触发）
sudo systemctl start nonexistent-service
# AIS 会自动分析错误并提供解决方案

# 主题学习
ais learn git

# 查看学习报告
ais report                    # 文本格式报告
ais report --html --open      # HTML可视化报告

# 查看历史记录
ais history
```

## 🌟 使用场景

### 开发者
- **调试代码**：快速分析编译错误、运行时错误
- **环境配置**：解决依赖安装、环境配置问题
- **工具使用**：学习 Git、Docker、Kubernetes 等工具

### 系统管理员
- **系统诊断**：分析系统错误、服务问题
- **网络排障**：诊断网络连接、DNS 解析问题
- **权限管理**：解决用户权限、文件权限问题

### 学习者
- **技能提升**：系统化学习命令行工具
- **经验积累**：将错误转化为学习机会
- **进度跟踪**：通过学习报告了解自己的成长

## 🎨 用户体验

### 美观的界面
- **Rich 库美化**：彩色输出、进度条、表格
- **交互式菜单**：支持快捷键和智能排序
- **流式输出**：实时显示 AI 处理进度

### 智能交互
- **上下文感知**：根据当前环境提供更准确的建议
- **个性化推荐**：基于用户历史行为的智能建议
- **风险评估**：智能评估命令风险等级

### 隐私保护
- **本地存储**：所有数据存储在本地 SQLite 数据库
- **敏感信息过滤**：自动过滤密码、API 密钥等敏感信息
- **可配置的上下文级别**：用户可控制信息收集范围

## 🔧 技术特性

### 架构设计
- **模块化设计**：清晰的代码结构，易于扩展和维护
- **插件系统**：支持自定义插件和扩展
- **异步处理**：高性能的异步 I/O 处理

### 多平台支持
- **跨平台**：支持 Linux、macOS、Windows（WSL）
- **多 Shell 支持**：支持 Bash、Zsh，自动检测Shell类型
- **容器化**：提供 Docker 镜像，支持容器化部署
- **多发行版支持**：自动适配Ubuntu、CentOS、Debian、Rocky Linux等20+发行版

### 数据管理
- **本地数据库**：使用 SQLite 存储用户数据（`~/.local/share/ais/`）
- **配置管理**：TOML格式配置文件（`~/.config/ais/config.toml`）
- **隐私保护**：敏感数据过滤，支持本地AI模型

---

## 功能导航

| 功能 | 描述 | 链接 |
|------|------|------|
| [错误分析](./error-analysis) | 智能错误分析和解决方案 | 🧠 |
| [AI 问答](./ai-chat) | 智能问答助手 | 💬 |
| [学习系统](./learning-system) | 系统化技术学习 | 📚 |
| [学习报告](./learning-reports) | 文本格式个性化学习报告 | 📊 |
| [HTML可视化报告](./html-reports) | 交互式图表可视化报告 | 📈 |
| [提供商管理](./provider-management) | AI 服务提供商管理 | ⚙️ |

---

## 下一步

- [安装指南](../getting-started/installation.md) - 开始安装 AIS
- [快速开始](../getting-started/quick-start.md) - 5 分钟快速上手
- [错误分析](./error-analysis.md) - 了解错误分析功能
- [AI 问答](./ai-chat.md) - 了解 AI 问答功能
- [学习系统](./learning-system.md) - 了解学习系统功能

---

::: tip 提示
AIS 的核心理念是将每次错误都转化为学习机会，帮助用户不断提升技能水平。
:::

::: info 开源项目
AIS 是一个开源项目，欢迎大家贡献代码和建议。
:::

::: warning 注意
AIS 优先保护用户隐私，所有数据本地存储，支持完全离线使用。
:::
